{#
# This file is part of Invenio.
# Copyright (C) 2013, 2014, 2015, 2016 CERN.
#
# Invenio is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
#
# In applying this license, CERN does not
# waive the privileges and immunities granted to it by virtue of its status
# as an Intergovernmental Organization or submit itself to any jurisdiction.
#}

{% extends config.SEARCH_UI_SEARCH_TEMPLATE %}

{%- from "invenio_communities/macros.html" import community_header %}

{% set title = community.title + " | " + config.THEME_SITENAME %}
{% set search_hidden_params = {"provisional_communities": community.id} %}

{%- block page_header %}
{% set search_input_placeholder = "Search " + community.title %}
{% include "invenio_search_ui/header.html" %}
{%- endblock page_header %}

{%- block css %}
  {{ super() }}
  {% assets "invenio_communities_css" %}<link href="{{ ASSET_URL }}" rel="stylesheet">{% endassets %}
{%- endblock css %}

{%- block javascript -%}
  {{ super() }}
  {% assets "invenio_communities_js" %}<script src="{{ ASSET_URL }}"></script>{% endassets %}
{%- endblock javascript -%}

{% block page_body %}
<div class="communities">
  {{ community_header(community, subtitle='Pending Requests') }}
  {{super()}}
</div>
{% endblock page_body %}

{%- block body_inner %}
<div id="invenio-communities-search">
  {{super()}}
</div>
{%- endblock body_inner %}

{%- block search_results %}
<invenio-search-results-provisional
 template="{{ url_for('static', filename=config.COMMUNITIES_JSTEMPLATE_RESULTS_CURATE) }}"
 community-curation-endpoint="{{ url_for('invenio_communities.curate', community_id=community.id) }}">
</invenio-search-results-provisional>
{%- endblock search_results %}

