{#
# This file is part of Invenio.
# Copyright (C) 2013, 2014 CERN.
#
# Invenio is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
#
# In applying this license, CERN does not
# waive the privileges and immunities granted to it by virtue of its status
# as an Intergovernmental Organization or submit itself to any jurisdiction.
#}

{% macro curation_buttons(bfo, comm_id, btnsize='', show_state=True, type='') %}
    {%- set recid = bfo.control_field('001') -%}
    {%- set caction = recid|curation_action(comm_id) -%}
    {%- set state = bfo|community_state(comm_id) -%}
    {%- if state == 'provisional' or show_state -%}
        {%- if caction or (state != 'provisional' and show_state) -%}
            {%- if caction == 'accept' or state == 'accepted' -%}
                {%- set accept_state = "disabled btn-success" -%}
                {%- set reject_state = "disabled" -%}
            {%- endif -%}
            {%- if caction == 'reject' or caction == 'remove' or state == 'rejected' -%}
                {%- set accept_state = "disabled" -%}
                {%- set reject_state = "disabled btn-danger" -%}
                {%- set greg = "DIPOL" -%}
            {%- endif -%}
        {%- else -%}
            {%- set accept_state = "" -%}
            {%- set reject_state = "" -%}
        {%- endif -%}
    {%- else -%}
        {%- if state == 'accepted' -%}
            {%- set accept_state = "hide" -%}
            {%- if caction == "remove" or caction == "reject" -%}
                {%- set reject_state = "disabled btn-danger" -%}
            {% else %}
                {%- set reject_state = "" -%}
            {%- endif -%}
        {%- endif -%}
    {%- endif -%}
    <span class="pull-right" id="curate_{{recid}}_{{comm_id}}{{'_rm' if type == 'remove' else ''}}">
        <span class="loader"><img src="{{ url_for('static', filename='img/ajax-loader.gif' ) }}" /></span>
        <span class="ajaxmsg text-muted" style="display: none;"></span>
        {% if type == 'remove' %}
        <button class="btn remove-coll-btn {{btnsize}} {{reject_state or 'btn-default'}}" {{ 'disabled' if reject_state else '' }} data-url="{{url_for('communities.curate')}}" data-recid="{{recid}}" data-collection="{{comm_id}}" data-toggle="tooltip" title="Remove this upload from the community collection"><i class="fa fa-times"></i> Remove</button>
        {% else %}
        <button class="btn accept-coll-btn {{btnsize}} {{accept_state or 'btn-default'}}" {{ 'disabled' if reject_state else '' }} data-url="{{url_for('communities.curate')}}" data-recid="{{recid}}" data-collection="{{comm_id}}" data-toggle="tooltip" title="Accept the inclusion of this upload into your community collection"><i class="fa fa-check"></i> Accept</button>
        <button class="btn reject-coll-btn {{btnsize}} {{reject_state or 'btn-default'}}" {{ 'disabled' if reject_state else '' }} data-url="{{url_for('communities.curate')}}" data-recid="{{recid}}" data-collection="{{comm_id}}" data-toggle="tooltip" title="Reject the inclusion of this upload into your community collection"><i class="fa fa-times"></i> Reject</button>
        {% endif %}
    </span>
{% endmacro %}
