{#
# This file is part of Invenio.
# Copyright (C) 2013, 2014, 2016 CERN.
#
# Invenio is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
#
# In applying this license, CERN does not
# waive the privileges and immunities granted to it by virtue of its status
# as an Intergovernmental Organization or submit itself to any jurisdiction.
#}
<a href="TODO url for upload with community id" class="btn btn-primary btn-lg signup pull-right">Upload</a>
<h4>Want your upload to appear in this community?</h4>
<ul>
    <li>Click the button to upload straight to this community.</li>
    <li>The community curator is notified, and will either accept or reject your upload (see community curation policy above).</li>
    <li>{{ _("If your upload is rejected by the curator, it will still be available on %(name)s, just not in this community.", name=config.CFG_SITE_NAME) }}</li>
</ul>
