{#
# This file is part of Invenio.
# Copyright (C) 2013, 2014, 2016 CERN.
#
# Invenio is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
#
# In applying this license, CERN does not
# waive the privileges and immunities granted to it by virtue of its status
# as an Intergovernmental Organization or submit itself to any jurisdiction.
#}
<small class="text-muted">Provisional community collection</small>
<h4>{{community.title}}</h4>
<hr>
{% if community.has_logo %}<img src="{{community.logo_url}}" class="pull-right" style="padding: 2px;">{% endif %}

<p>This is a restricted provisional community collection used by the curator to accept/reject new uploads for this community.</p>
<p>To browse the community collection, go to the <a href="{{community.community_url}}">public community collection</a>.</p>
